#!/bin/sh

. ./build-env.sh

export ARCH=arm64
if [ "X${BSP_ARCH}" = "Xarmhf" ]; then
  export ARCH=arm
  export CROSS_COMPILE=arm-linux-gnueabihf-

elif [ "X${BSP_ARCH}" = "Xamd64" ]; then
  export ARCH=x86
  export CROSS_COMPILE=x86_64-linux-gnu-

elif [ "X${BSP_ARCH}" = "Xi686" ]; then
  export ARCH=x86
  export CROSS_COMPILE=i686-linux-gnu-
fi

export LOCALVERSION="+${BSP_MODEL}"

defcfg=${BSP_CONFIG}_defconfig
if [ "x$1" != "x" ] ; then
  defcfg=$1
fi

lxcfg=arch/${ARCH}/configs/${defcfg}


change_lxcfg() {
  c=${lxcfg}
  if [ "x$2" = "x-" ]; then
    sed -i 's|'"$1"'||g' $c
  elif [ "x$2" = "xn" ]; then
    if grep -q -E $1'=.*' $c ; then
      sed -i 's|'$1'=.*|# '$1' is not set|g' $c
    elif ! grep -q '# '$1' is not set' $c ; then
      echo '# '$1' is not set' >> $c
    fi
  else
    if grep -q $1'='$2 $c ; then
      true
    elif grep -q -E $1'=.*' $c ; then
      sed -i 's|'$1'=.*|'$1'='$2'|g' $c
    elif grep -q '# '$1' is not set' $c ; then
      sed -i 's|# '$1' is not set|'$1'='$2'|g' $c
    else
      echo $1'='$2 >> $c
    fi
  fi
}


cd linux

c=${defcfg}
c=${c/_defconfig/}
if [ -e ../patches/${c}_defconfig ]; then
  if [ -e arch/${ARCH}/configs/${c}_defconfig ]; then
    if [ ! -e arch/${ARCH}/configs/${c}_git_defconfig ]; then
      mv arch/${ARCH}/configs/${c}_defconfig arch/${ARCH}/configs/${c}_git_defconfig
    fi
  fi

  if [ ! -e arch/${ARCH}/configs/${c}_defconfig ]; then
    cp -p ../patches/${c}_defconfig arch/${ARCH}/configs/
    if [ ! -e arch/${ARCH}/configs/${c}_git_defconfig ]; then
      cp -p arch/${ARCH}/configs/${c}_defconfig arch/${ARCH}/configs/${c}_git_defconfig
    fi
  fi
fi

if ! grep -q 'CONFIG_MODULES=y' ${lxcfg} ; then
  change_lxcfg 'CONFIG_MODULES' y
  change_lxcfg 'CONFIG_MODULE_FORCE_LOAD' y
  change_lxcfg 'CONFIG_MODULE_UNLOAD' y
  change_lxcfg 'CONFIG_MODULE_FORCE_UNLOAD' y
  change_lxcfg 'CONFIG_MODVERSIONS' n
  change_lxcfg 'CONFIG_MODULE_SRCVERSION_ALL' n
  change_lxcfg 'CONFIG_MODULE_SIG' n
  change_lxcfg 'CONFIG_MODULE_COMPRESS' n
fi

change_lxcfg 'CONFIG_LOGO' y
change_lxcfg 'CONFIG_LOGO_LINUX_MONO' n
change_lxcfg 'CONFIG_LOGO_LINUX_VGA16' n
change_lxcfg 'CONFIG_LOGO_LINUX_CLUT224' y

change_lxcfg 'CONFIG_IP_ROUTE_MULTIPATH' y

change_lxcfg 'CONFIG_BLK_DEV_NBD' m

change_lxcfg 'CONFIG_TASKSTATS' y

change_lxcfg 'CONFIG_TASK_DELAY_ACCT' y
change_lxcfg 'CONFIG_TASK_XACCT' y
change_lxcfg 'CONFIG_TASK_IO_ACCOUNTING' y

change_lxcfg 'CONFIG_INPUT_JOYDEV' y
change_lxcfg 'CONFIG_INPUT_JOYSTICK' y

change_lxcfg 'CONFIG_JOYSTICK_ANALOG' m
change_lxcfg 'CONFIG_JOYSTICK_A3D' m
change_lxcfg 'CONFIG_JOYSTICK_ADI' m
change_lxcfg 'CONFIG_JOYSTICK_COBRA' m
change_lxcfg 'CONFIG_JOYSTICK_GF2K' m
change_lxcfg 'CONFIG_JOYSTICK_GRIP' m
change_lxcfg 'CONFIG_JOYSTICK_GRIP_MP' m
change_lxcfg 'CONFIG_JOYSTICK_GUILLEMOT' m
change_lxcfg 'CONFIG_JOYSTICK_INTERACT' m
change_lxcfg 'CONFIG_JOYSTICK_SIDEWINDER' m
change_lxcfg 'CONFIG_JOYSTICK_TMDC' m
change_lxcfg 'CONFIG_JOYSTICK_IFORCE' m
change_lxcfg 'CONFIG_JOYSTICK_IFORCE_USB' y
change_lxcfg 'CONFIG_JOYSTICK_IFORCE_232' y
change_lxcfg 'CONFIG_JOYSTICK_WARRIOR' m
change_lxcfg 'CONFIG_JOYSTICK_MAGELLAN' m
change_lxcfg 'CONFIG_JOYSTICK_SPACEORB' m
change_lxcfg 'CONFIG_JOYSTICK_SPACEBALL' m
change_lxcfg 'CONFIG_JOYSTICK_STINGER' m
change_lxcfg 'CONFIG_JOYSTICK_TWIDJOY' m
change_lxcfg 'CONFIG_JOYSTICK_ZHENHUA' m
change_lxcfg 'CONFIG_JOYSTICK_AS5011' m
change_lxcfg 'CONFIG_JOYSTICK_JOYDUMP' m
change_lxcfg 'CONFIG_JOYSTICK_XPAD' m
change_lxcfg 'CONFIG_JOYSTICK_XPAD_FF' y
change_lxcfg 'CONFIG_JOYSTICK_XPAD_LEDS' y

change_lxcfg 'CONFIG_SERIO' m
change_lxcfg 'CONFIG_GAMEPORT' m

change_lxcfg 'CONFIG_SOUND_OSS_CORE' y

change_lxcfg 'CONFIG_SND_MIXER_OSS' m
change_lxcfg 'CONFIG_SND_PCM_OSS' m

change_lxcfg 'CONFIG_SND_SEQUENCER_OSS' y

change_lxcfg 'CONFIG_SND_SUPPORT_OLD_API' y

change_lxcfg 'CONFIG_SND_SPI' y

change_lxcfg 'CONFIG_FSCACHE' m

change_lxcfg 'CONFIG_CIFS' m
change_lxcfg 'CONFIG_CIFS_STATS' y
change_lxcfg 'CONFIG_CIFS_STATS2' y
change_lxcfg 'CONFIG_CIFS_WEAK_PW_HASH' y
change_lxcfg 'CONFIG_CIFS_UPCALL' y
change_lxcfg 'CONFIG_CIFS_XATTR' y
change_lxcfg 'CONFIG_CIFS_POSIX' y
change_lxcfg 'CONFIG_CIFS_ACL' y
change_lxcfg 'CONFIG_CIFS_DEBUG' n
change_lxcfg 'CONFIG_CIFS_DFS_UPCALL' y
change_lxcfg 'CONFIG_CIFS_SMB2' y
#change_lxcfg 'CONFIG_CIFS_SMB311' n

#change_lxcfg 'CONFIG_F2FS_FS' n

change_lxcfg 'CONFIG_ANDROID_PARANOID_NETWORK' n

make LOCALVERSION="${LOCALVERSION}" ARCH=${ARCH} CROSS_COMPILE=${CROSS_COMPILE} ${defcfg}

# optional
if grep -q '# CONFIG_LIBERTAS is not set' .config ; then
  sed -i 's|# CONFIG_LIBERTAS is not set|CONFIG_LIBERTAS=m\
CONFIG_LIBERTAS_USB=m\
# CONFIG_LIBERTAS_SDIO is not set\
# CONFIG_LIBERTAS_SPI is not set\
# CONFIG_LIBERTAS_DEBUG is not set\
# CONFIG_LIBERTAS_MESH is not set\
# CONFIG_LIB80211_DEBUG is not set|g' .config
fi

sed -i 's|# CONFIG_GAMEPORT_NS558 is not set|CONFIG_GAMEPORT_NS558=m|g' .config
sed -i 's|# CONFIG_GAMEPORT_L4 is not set|CONFIG_GAMEPORT_L4=m|g' .config
#sed -i 's|# CONFIG_SND_ALOOP is not set|CONFIG_SND_ALOOP=m|g' .config
sed -i 's|# CONFIG_SND_VIRMIDI is not set|CONFIG_SND_VIRMIDI=m|g' .config

make LOCALVERSION="${LOCALVERSION}" ARCH=${ARCH} CROSS_COMPILE=${CROSS_COMPILE} oldconfig

cd ..

echo OK
