#!/bin/sh

. ./build-env.sh

lxmmmkb=`echo ${lxdebkb} | cut -d '.' -f 1-2`

if [ ! -e linux-odroidn1-4.4.y ]; then
  #git clone -b odroidn1-4.4.y --depth 1 https://github.com/hardkernel/linux linux-odroidn1-4.4.y
  #git clone -b release-4.4 --depth 1 https://github.com/rockchip-linux/kernel linux-odroidn1-4.4.y
  #git clone -b odroidn1-4.4.y --depth 1 https://github.com/Owersun/linux-hardkernel linux-odroidn1-4.4.y
  git clone -b rocksbc-4.4.y --depth 1 https://github.com/scpcom/linux-owersun-4.4.y linux-odroidn1-4.4.y
fi

echo "Copying files from linux-${lxmmmkb}.y git..."
mkdir linux && \
cp -apP linux-odroidn1-4.4.y/. linux/

cd linux

VERSION=`cat Makefile | grep -E '^VERSION.=' | cut -d "=" -f 2- | tr -d " \t\n\r"`
PATCHLEVEL=`cat Makefile | grep PATCHLEVEL.= | cut -d "=" -f 2- | tr -d " \t\n\r"`
SUBVERSION=`cat Makefile | grep SUBLEVEL.= | cut -d "=" -f 2- | tr -d " \t\n\r"`

quiltpatches() {
  if [ -e ../patches/$2 ]; then
    mkdir -p patches/$1

    for p in `cat ../patches/$2 | grep -v '^#' | grep patch` ; do
      b=`basename $p`

      if [ -e ../patches/${p} ]; then
        cp -p ../patches/${p} patches/${p}
      else
        cp -p  ../patches/${b} patches/${p}
      fi
    done

    cat ../patches/$2 >> patches/series

    quilt push -a
  fi

}

gitpatches() {
  if [ -e ../patches/$2 ]; then
    echo ""
    echo "Apply series patches/$2"
    echo ""

    mkdir -p patches/$1

    l=none
    for p in `cat ../patches/$2 | grep -v '^#' | grep patch` ; do
      b=`basename $p`
      d=`dirname $p`
      l=${p}
      n=`echo $b | sed s/\.patch$//g`

      if [ -e ../patches/${p} ]; then
        cp -p ../patches/${p} patches/${p}
      else
        cp -p  ../patches/${b} patches/${p}
      fi

      echo "Apply patch patches/${p}"

      #if grep -q '\\r' patches/${p} ; then
      #  sed -i -e 's/\r$//g' patches/${p}
      #fi

      nogitam=1
      gitamcont=0
      #if grep -m1 -q "^From ${n} Mon Sep 17 00:00:00 2001" patches/${p} ; then
      if grep -m1 -q "^From ........................................ Mon Sep 17 00:00:00 2001" patches/${p} ; then
        c=`grep -m1 "^From ........................................ Mon Sep 17 00:00:00 2001" patches/${p} | sed s/'^From '//g | cut -d ' ' -f1`

        sed -i -e "0,/^---$/ s/^---$/\n${d} ${c}\n---/" patches/${p}

        if git am < patches/${p} ; then
          nogitam=0
        else
          gitamcont=1
          #git am --skip
        fi
      fi

      if [ $nogitam = 1 ]; then
        if ! git apply --stat --apply patches/${p} ; then
          #git apply --stat --apply --3way patches/${p}
          #sed -i -e 's/\r$//g' patches/${p}
          patch -p1 --no-backup-if-mismatch < patches/${p}
          echo ${p} >> patches/series-no-git
        else
          echo ${p} >> patches/series-no-am
        fi
      fi

      if echo $n | grep -q -E '^linux-' ; then
        n=`echo $n | sed s/^linux-4\.4\.y-//g`

      elif grep -m1 -q "^From ${n} Mon Sep 17 00:00:00 2001" patches/${p} ; then
        if ! grep -q '^---$' patches/${p} ; then
          exit 1
        fi

      else
        exit 1
      fi

      if [ $nogitam = 1 ]; then
        echo git commit -m "${d} ${n}"
        git add .
        #git commit -m "${d} ${n}"
        #echo "${d} ${n}" > patches/${p}.msg

        if grep -m1 -q "^From ........................................ Mon Sep 17 00:00:00 2001" patches/${p} ; then
          if ! grep -q '^---$' patches/${p} ; then
            exit 1
          fi
          cat patches/${p} | grep -m1 -B399 '^---$' | sed /^---$/d | grep -m1 -A399 '^Subject:' | sed s/'^Subject: '/''/g > patches/${p}.msg
        else
          echo "${d} ${n}" > patches/${p}.msg
        fi
        
        if [ $gitamcont = 1 ]; then
          git am --continue
        else
          git commit -F patches/${p}.msg
        fi
      fi

      echo ""
    done

    echo "Now in patch patches/${l}"
    cat ../patches/$2 >> patches/series

    #quilt push -a
  fi

}

applypatches() {
  gitpatches $1 $2
}

#cp -apP ../patches/. patches/platform/
#mv patches/platform/owersun patches/
#cat ../patches/series-platform >> patches/series
#quilt push -a

mkdir -p patches/mainline
mkdir -p patches/owersun

applypatches platform series-platform

applypatches rockchip series-rockchip
applypatches rockchip series-fscrypt
applypatches rockchip series-media-rc
applypatches rockchip series-zram

applypatches rockchip series-rockchip-20190125
applypatches rockchip series-rockchip-20190220
applypatches rockchip series-rockchip-20190516
applypatches rockchip series-rockchip-20190617
applypatches rockchip series-rockchip-20190628
applypatches rockchip series-rockchip-20190927
applypatches rockchip series-rockchip-20191029
applypatches rockchip series-rockchip-20200120
applypatches rockchip series-rockchip-20200316
applypatches rockchip series-rockchip-99991231

applypatches ayufan series-ayufan

applypatches radxa series-radxa

VERSION=`cat Makefile | grep -E '^VERSION.=' | cut -d "=" -f 2- | tr -d " \t\n\r"`
PATCHLEVEL=`cat Makefile | grep PATCHLEVEL.= | cut -d "=" -f 2- | tr -d " \t\n\r"`
SUBVERSION=`cat Makefile | grep SUBLEVEL.= | cut -d "=" -f 2- | tr -d " \t\n\r"`

if [ -e ../patches/mainline ]; then
  #mkdir -p patches/mainline
  #mv patches/platform/mainline/*.patch patches/mainline/
  for s in `ls ../patches/series-mainline-???` ; do
    b=`basename $s`
    v=`basename $s | cut -d '-' -f 3`
    if [ $SUBVERSION -lt $v ]; then
      echo ""
      applypatches mainline ${b}
      #echo ""
      #echo "" >> patches/series
      #cat $s >> patches/series
      #quilt push -a
    fi
  done
fi

# binary patches
gitpatches rockchip series-binary

#git apply patches/rockchip/0550094bdb94e316c5f0b64b84a428c9f55f8cb0.patch
#git apply patches/rockchip/9579567b7dbcc961a670ed6a9463b2b4bd60ceac.patch

pcount=`cat patches/series | grep -v -E '^#' | grep patch | wc -l`

mv patches/series patches/series-git

echo ""

if [ -e patches/series-no-am -a -e patches/series-no-git ]; then
  acount=`cat patches/series-no-am  | grep -v -E '^#' | grep patch | wc -l`
  ncount=`cat patches/series-no-git | grep -v -E '^#' | grep patch | wc -l`
  echo "Applied ${pcount} patches (${acount} with git apply, ${ncount} outside git)."
elif [ -e patches/series-no-git ]; then
  ncount=`cat patches/series-no-git | grep -v -E '^#' | grep patch | wc -l`
  echo "Applied ${pcount} patches (${ncount} outside git)."
else
  echo "Applied ${pcount} patches."
fi

echo ""

for f in ../patches/*_defconfig ; do
  c=`basename $f`
  c=${c/_defconfig/}

  if grep -q '^CONFIG_ARM64=y' $f ; then
    if [ -e arch/arm64/configs/${c}_defconfig ]; then
     mv arch/arm64/configs/${c}_defconfig arch/arm64/configs/${c}_git_defconfig
    fi
    cp -p $f arch/arm64/configs/
  fi
done

git add arch/arm64/configs
git commit -m "arm64: configs: add rk33 defconfigs"

for f in ../patches/*_defconfig ; do
  c=`basename $f`
  c=${c/_defconfig/}

  if grep -q '^CONFIG_ARM_.*=y' $f ; then
  if ! grep -q '^CONFIG_ARM64=y' $f ; then
    if [ -e arch/arm/configs/${c}_defconfig ]; then
     mv arch/arm/configs/${c}_defconfig arch/arm/configs/${c}_git_defconfig
    fi
    cp -p $f arch/arm/configs/
  fi
  fi
done

git add arch/arm/configs
git commit -m "arm: configs: add rk32 defconfigs"

for f in ../patches/*_ubuntu_defconfig ; do
  c=`basename $f`
  c=${c/_defconfig/}

  if grep -q '^CONFIG_X86_.*=y' $f ; then
    if [ -e arch/x86/configs/${c}_defconfig ]; then
     mv arch/x86/configs/${c}_defconfig arch/x86/configs/${c}_git_defconfig
    fi
    cp -p $f arch/x86/configs/
  fi
done

git add arch/x86/configs
git commit -m "x86: configs: add ubuntu defconfigs"

tar xzf ../linux-4.4.y-odroidn1-firmware-edid.tar.gz

echo OK
